#!/bin/bash

APT_GET=/usr/bin/apt-get
RPL=/usr/bin/rpl
CP=/bin/cp
RM=/bin/rm
USERADD=/usr/sbin/useradd
USERDEL=/usr/sbin/userdel
OPENSSL=/usr/bin/openssl
CHOWN=/bin/chown
CHMOD=/bin/chmod
MKDIR=/bin/mkdir
LN=/bin/ln
CAT=/bin/cat
ECHO=/bin/echo
MKTEMP=/bin/mktemp
PWGEN=/usr/bin/pwgen
UPDATE_RC_D=/usr/sbin/update-rc.d

#######################################################################################################################################
## Edit this values
SYSTEM_USER=bitcoin
RPC_USER=bitcoin
##SSL CERT DATA
DAYS=3650
COUNTRYNAME=AR ##2 letter code
STATEORPROVINCENAME="BUENOS AIRES"
LOCALITYNAME=CABA
ORGANITATIONNAME=GeekLab
ORGANITATIONALUNITNAME=GeekLab
COMMONNAME=geeklab.com.ar
EMAILADDRESS=rmalvarez@gnupanel.org
FILE_PEM=bitcoin-init.pem
FILE_CERT=bitcoin-init.cert
#######################################################################################################################################

COMMAND_IN=$1
SYSTEM_USER_DIR=/var/lib/${SYSTEM_USER}

if [ "${COMMAND_IN}" = "uninstall" ]
then
    ${UPDATE_RC_D} bitcoin-init.sh remove
    ${USERDEL} ${SYSTEM_USER}

    if [ -f ${SYSTEM_USER_DIR}/.bitcoin/wallet.dat ]
    then
	${CP} -f ${SYSTEM_USER_DIR}/.bitcoin/wallet.dat .
    fi

    ${RM} -f -r ${SYSTEM_USER_DIR}
    ${RM} -f /etc/default/bitcoin-init
    ${RM} -f /etc/init.d/bitcoin-init.sh
    ${RM} -f /usr/local/bin/bitcoin-init.sh
    exit 0
fi

if ! [ -e /usr/bin/bitcoind ]
then
    ${ECHO} "/usr/bin/bitcoind not exists"
    ${ECHO} "First install bitcoind package"
    exit 1
fi

${APT_GET} install coreutils openssl rpl passwd pwgen
RPC_PASSWORD=`${PWGEN} -s 13 -1 -N 1`

${USERADD} --home ${SYSTEM_USER_DIR} -m --shell /bin/bash ${SYSTEM_USER}
${MKDIR} -p ${SYSTEM_USER_DIR}/.bitcoin
${CHOWN} ${SYSTEM_USER}:${SYSTEM_USER} ${SYSTEM_USER_DIR}/.bitcoin
${CHMOD} 0700 ${SYSTEM_USER_DIR}/.bitcoin

${CP} -f etc/default/bitcoin-init /etc/default/bitcoin-init
${RPL} __SYSTEM_USER_DIR__ ${SYSTEM_USER_DIR} /etc/default/bitcoin-init
${RPL} __SYSTEM_USER__ ${SYSTEM_USER} /etc/default/bitcoin-init
${CHOWN} root:root /etc/default/bitcoin-init
${CHMOD} 0444 /etc/default/bitcoin-init

${CP} -f .bitcoin/bitcoin-server.conf ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${RPL} __BITCOIN_RPC_USER__ ${RPC_USER} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${RPL} __BITCOIN_RPC_PASSWORD__ ${RPC_PASSWORD} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${RPL} __FILE_PEM__ ${FILE_PEM} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${RPL} __FILE_CERT__ ${FILE_CERT} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${CHOWN} ${SYSTEM_USER}:${SYSTEM_USER} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf
${CHMOD} 0400 ${SYSTEM_USER_DIR}/.bitcoin/bitcoin-server.conf

${CP} -f .bitcoin/bitcoin.conf ${SYSTEM_USER_DIR}/.bitcoin/bitcoin.conf
${RPL} __BITCOIN_RPC_USER__ ${RPC_USER} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin.conf
${RPL} __BITCOIN_RPC_PASSWORD__ ${RPC_PASSWORD} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin.conf
${CHOWN} ${SYSTEM_USER}:${SYSTEM_USER} ${SYSTEM_USER_DIR}/.bitcoin/bitcoin.conf
${CHMOD} 0400 ${SYSTEM_USER_DIR}/.bitcoin/bitcoin.conf

${CP} -f usr/local/bin/bitcoin-init.sh /usr/local/bin/bitcoin-init.sh
${CHOWN} root:root /usr/local/bin/bitcoin-init.sh
${CHMOD} 0544 /usr/local/bin/bitcoin-init.sh

${LN} -s /usr/local/bin/bitcoin-init.sh /etc/init.d/bitcoin-init.sh

${UPDATE_RC_D} bitcoin-init.sh defaults

SSL_EAY_FILE=`${MKTEMP}`

${CP} -f .bitcoin/ssleay.cnf ${SSL_EAY_FILE}

if [ -f ${FILE_PEM} ]
then
    ${RM} -f ${FILE_PEM}
fi

if [ -f ${FILE_CERT} ]
then
    ${RM} -f ${FILE_CERT}
fi

${RPL} __COUNTRY__ "${COUNTRYNAME}" ${SSL_EAY_FILE}
${RPL} __STATE__ "${STATEORPROVINCENAME}" ${SSL_EAY_FILE}
${RPL} __LOCALITY__ "${LOCALITYNAME}" ${SSL_EAY_FILE}
${RPL} __ORGANITATION__ "${ORGANITATIONNAME}" ${SSL_EAY_FILE}
${RPL} __ORGANITATION_UNIT__ "${ORGANITATIONALUNITNAME}" ${SSL_EAY_FILE}
${RPL} __COMMON_NAME__ "${COMMONNAME}" ${SSL_EAY_FILE}
${RPL} __EMAIL__ "${EMAILADDRESS}" ${SSL_EAY_FILE}

${OPENSSL} genrsa -out ${FILE_PEM} 4096
${OPENSSL} req -new -config ${SSL_EAY_FILE} -x509 -nodes -sha1 -days ${DAYS} -key ${FILE_PEM} > ${FILE_CERT}

${CP} -f ${FILE_PEM} ${SYSTEM_USER_DIR}/.bitcoin/${FILE_PEM}
${CHOWN} ${SYSTEM_USER}:${SYSTEM_USER} ${SYSTEM_USER_DIR}/.bitcoin/${FILE_PEM}
${CHMOD} 0400 ${SYSTEM_USER_DIR}/.bitcoin/${FILE_PEM}

${CP} -f ${FILE_CERT} ${SYSTEM_USER_DIR}/.bitcoin/${FILE_CERT}
${CHOWN} ${SYSTEM_USER}:${SYSTEM_USER} ${SYSTEM_USER_DIR}/.bitcoin/${FILE_CERT}
${CHMOD} 0400 ${SYSTEM_USER_DIR}/.bitcoin/${FILE_CERT}

${RM} -f ${SSL_EAY_FILE}

if [ -f ${FILE_PEM} ]
then
    ${RM} -f ${FILE_PEM}
fi

if [ -f ${FILE_CERT} ]
then
    ${RM} -f ${FILE_CERT}
fi
